# (generated with --quick)

from typing import Any

Card: Any
DailyTrendCard: Any
Pageview: Any
PageviewStaff: Any
StaffModelDetailView: Any
StaffModelListView: Any
StaffModelViewset: Any
register_viewset: Any

class DailyPageviewsCard(Any):
    datetime_field: str
    model: Any
    size: Any
    title: str

class UserPageviewsCard(Any):
    template_name: str
    title: str
    def get_template_context(self) -> Any: ...



from plain.urls import RouterBase, path, register_router

from . import views


@register_router
class Router(RouterBase):
    namespace = "pageviews"
    urls = [
        path("track/", views.TrackView, name="track"),
    ]



# (generated with --quick)

import uuid
from plain import models
from plain.models import migrations
from typing import Any

class Migration(Any):
    dependencies: list[tuple[str, str]]
    operations: list
